@@ -5,10 +5,10 @@ package Strict::Perl;
 #
 # http://search.cpan.org/dist/Strict-Perl/
 #
-# Copyright (c) 2014 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2014, 2015 INABA Hitoshi <ina@cpan.org>
 ######################################################################
 
-$Strict::Perl::VERSION = 2014.10;
+$Strict::Perl::VERSION = 2015.06;
 
 use 5.00503;
 use strict;
@@ -297,18 +297,34 @@ sub import {
 
     # disable considered statements and variables
     if (open(SCRIPT,$0)) {
-        local $.;
-        while (<SCRIPT>) {
-            if (/ \b (
-                goto   | redo   | until    | foreach |
+        @_ = <SCRIPT>;
+        close(SCRIPT);
+        my $line = 1;
+
+        # skip #line NNN
+        if (grep(/^[#]line\s+[0-9]+/x,@_)){
+            while ($_ = shift @_) {
+                $line++;
+                if (/^[#]line\s+[0-9]+/x) {
+                    last;
+                }
+            }
+        }
+
+        while ($_ = shift @_) {
+            if (/^__END__$/x) {
+                last;
+            }
+            if (/ (?<! [A-Za-z_0-9\$\@%&*':>] ) (
+                goto   | redo   | until    | foreach  |
                 format | write  | formline |
-                msgctl | msgget | msgrcv   | msgsnd  |
+                msgctl | msgget | msgrcv   | msgsnd   |
                 semctl | semget | semop    |
                 shmctl | shmget | shmread  | shmwrite |
                 given  | when
 
             ) \b /x) { # Oops! I did little overkill.
-                die "Use of '$1' statement deprecated in line $.\n";
+                die "Use of '$1' statement deprecated in line $line\n";
             }
             elsif (/ (
                 \$ARRAY_BASE \b                            | \$\[     |
@@ -336,18 +352,18 @@ sub import {
                 \$ACCUMULATOR \b                           | \$\^A \b
 
             ) /x) {
-                die "Use of special variable '$1' deprecated in line $.\n";
+                die "Use of special variable '$1' deprecated in line $line\n";
             }
             elsif (/ ( ~~ ) /x) {
-                die "Use of operator '$1' deprecated in line $.\n";
+                die "Use of operator '$1' deprecated in line $line\n";
             }
             for my $mustword (@mustword) {
                 if (/ \b $mustword \b /x) {
                     $used{$mustword} = 1;
                 }
             }
+            $line++;
         }
-        close(SCRIPT);
     }
 
     for my $mustword (@mustword) {
@@ -369,7 +385,7 @@ Strict::Perl - Perl module to restrict old/unsafe constructs
 
 =head1 SYNOPSIS
 
-  use Strict::Perl 2014.10; # must version, must match
+  use Strict::Perl 2015.06; # must version, must match
 
 =head1 DESCRIPTION
 
@@ -381,15 +397,16 @@ in your script.
 
 Version specify is required when use Strict::Perl, like;
 
-  use Strict::Perl 2014.10;
+  use Strict::Perl 2015.06;
 
 It's die if specified version doesn't match Strict::Perl's version.
 
 On Perl 5.010001 or later, Strict::Perl works as;
 
   use strict;
-  use warnings qw(FATAL all);
-  use Fatal qw( # by compatible routine in Strict::Perl
+  use warnings qw(FATAL all); # not follow incompatible version-up of warnings.pm
+  use Fatal # by compatible routine in Strict::Perl
+  qw(
       seek sysseek
       dbmclose dbmopen
       binmode close chmod chown fcntl flock ioctl open sysopen truncate
@@ -409,8 +426,9 @@ On Perl 5.010001 or later, Strict::Perl works as;
 On Perl 5.006 or later,
 
   use strict;
-  use warnings qw(FATAL all);
-  use Fatal qw( # by compatible routine in Strict::Perl
+  use warnings qw(FATAL all); # not follow incompatible version-up of warnings.pm
+  use Fatal # by compatible routine in Strict::Perl
+  qw(
       seek sysseek
       dbmclose dbmopen
       binmode close chmod chown fcntl flock ioctl open sysopen truncate
@@ -427,8 +445,9 @@ On Perl 5.00503 or later,
 
   use strict;
   $^W = 1;
-  $SIG{__WARN__} = sub { die "$_[0]\n" };
-  use Fatal qw( # by compatible routine in Strict::Perl
+  $SIG{__WARN__} = sub { die "$_[0]\n" }; # not follow incompatible version-up of warnings.pm
+  use Fatal # by compatible routine in Strict::Perl
+  qw(
       seek sysseek
       dbmclose dbmopen
       binmode close chmod chown fcntl flock ioctl open sysopen truncate
